@@ -1,51 +1,47 @@
-from typing import Callable, Any
-from dataclasses import dataclass
+from argparse import Namespace
+from typing import Callable, Any, List
+from dataclasses import dataclass, field
+import abc
 
 
+@dataclass
+class Parameter:
+    """Class representing argparse parameter"""
+
+    name: str
+    help: str
+    action: str = None
+
+
+@dataclass
 class Command:
-    def __init__(
-        self,
-        name: str,
-        _help: str,
-        param: str = "",
-        param_help: str = "",
-        param_type: type = str,
-        param_required: bool = False,
-    ) -> None:
-        self.name = name
-        self.help = _help
-        self.param = param
-        self.param_help = param_help
-        self.param_type = param_type
-        self.param_required = param_required
+    __metaclass__ = abc.ABCMeta
+
+    """Class reprensenting argparse subparser"""
+    name: str
+    help: str
+    params: List[Parameter] = field(default_factory=list)
+
+    @abc.abstractmethod
+    def execute(self, args: Namespace = None) -> None:
+        """Execute the command
+
+        Args:
+            args (Namespace, optional): List of args provided by argparse. Defaults to None.
+        """
+        raise NotImplementedError()
 
 
+@dataclass
 class Group:
-    def __init__(
-        self,
-        _id: int,
-        name: str,
-        path: str,
-        description: str,
-        visibility: str,
-        web_url: str,
-        full_path: str,
-        parent_id: int,
-    ) -> None:
-        self.id = _id
-        self.name = name
-        self.path = path
-        self.description = description
-        self.visibility = visibility
-        self.web_url = web_url
-        self.full_path = full_path
-        self.parent_id = parent_id
-
-    def __str__(self) -> str:
-        return f'Group({self.id}, "{self.full_path}")'
-
-    def __repr__(self) -> str:
-        return self.__str__()
+    id: int
+    name: str
+    path: str
+    description: str
+    visibility: str
+    web_url: str
+    full_path: str
+    parent_id: int
 
 
 class Project:
@@ -60,6 +56,8 @@ class Project:
         open_issues_count: int,
         namespace_id: int,
         namespace_name: str,
+        ssh_url_to_repo: str,
+        http_url_to_repo: str,
     ) -> None:
         self.id = _id
         self.description = description
@@ -69,6 +67,8 @@ class Project:
         self.star_count = star_count
         self.open_issues_count = open_issues_count
         self.namespace = {"id": namespace_id, "name": namespace_name}
+        self.ssh_url_to_repo = ssh_url_to_repo
+        self.http_url_to_repo = http_url_to_repo
 
     def __str__(self) -> str:
         return f'Porject({self.id}, "{self.path_with_namespace}")'
@@ -83,28 +83,23 @@ class ProjectQuestion:
     name: str
     default: str
     help: str
-    res_type: type
     validate: Callable[[str], bool] = None
     transform: Callable[[str], bool] = None
-    response: Any = None
+    response: Any = field(init=False)
+
+    def __post_init__(self):
+        if self.message == "" or self.name == "":
+            raise ValueError("No value provided for message or name")
 
     def transform_response(self, response: Any) -> None:
         if response is None:
             return
-        
+
         if self.transform is not None:
             self.response = self.transform(response)
 
-    def set_response(self, response: Any) -> bool:
-        if not isinstance(response, self.res_type):
-            return False
-
+    def set_response(self, response: Any) -> None:
         if response is None:
             self.response = self.default
 
         self.response = response
-        
-        if self.validate is not None:
-            return self.validate(response)
-        
-        return True
